@@ -47,13 +47,14 @@ class MySQL(object):
             self.lock.release()
 
     def save(self, item, table_name):
-        self.db.ping(reconnect=True)
-        data = dict(item)
-        keys = ', '.join(data.keys())
-        values = ', '.join(['%s'] * len(data))
-        sql = 'INSERT IGNORE INTO {table} ({keys}) values ({values})'.format(table=table_name, keys=keys, values=values)
         try:
             self.lock.acquire()
+            self.db.ping(reconnect=True)
+            data = dict(item)
+            keys = ', '.join(data.keys())
+            values = ', '.join(['%s'] * len(data))
+            sql = 'INSERT IGNORE INTO {table} ({keys}) values ({values})'.format(table=table_name, keys=keys,
+                                                                                 values=values)
             if self.cursor.execute(sql, tuple(data.values())):
                 self.db.commit()
         except pymysql.MySQLError as e:
@@ -64,17 +65,17 @@ class MySQL(object):
 
     # 保存到mysql
     def write(self, item, table_name):
-        self.db.ping(reconnect=True)
-        data = dict(item)
-        keys = ', '.join(data.keys())
-        values = ', '.join(['%s'] * len(data))
-        sql = 'INSERT INTO {table}({keys}) VALUES ({values}) ON DUPLICATE KEY UPDATE'.format(table=table_name,
-                                                                                             keys=keys,
-                                                                                             values=values)
-        update = ','.join([" {key} = %s".format(key=key) for key in data])
-        sql += update
         try:
             self.lock.acquire()
+            self.db.ping(reconnect=True)
+            data = dict(item)
+            keys = ', '.join(data.keys())
+            values = ', '.join(['%s'] * len(data))
+            sql = 'INSERT INTO {table}({keys}) VALUES ({values}) ON DUPLICATE KEY UPDATE'.format(table=table_name,
+                                                                                                 keys=keys,
+                                                                                                 values=values)
+            update = ','.join([" {key} = %s".format(key=key) for key in data])
+            sql += update
             if self.cursor.execute(sql, tuple(data.values()) * 2):
                 self.db.commit()
         except pymysql.MySQLError as e:
